const path = require('path')
const fs = require('fs')
const util = require('util')
const axios = require('axios')

const getAbsolutePath = pathStr =>
  path.isAbsolute(pathStr) ? pathStr : path.resolve(__dirname, pathStr)

const asyncRead = util.promisify(fs.readFile)
const asyncWrite = util.promisify(fs.writeFile)

const read = from => {
  try {
    const absoluteFrom = getAbsolutePath(from)
    return asyncRead(absoluteFrom)
  } catch (error) {
    console.error('read', error)
  }
}

const write = async (to, data) => {
  try {
    const absoluteTo = getAbsolutePath(to)
    await asyncWrite(absoluteTo, data)
  } catch (error) {
    console.error('write', error)
  }
}

exports.write = write

const copy = async (from, to) => {
  try {
    const data = await read(from)
    await write(to, data)
  } catch (error) {
    console.error('copy failed', error)
  }
}

const getCityWeather = async (city, to = './text.txt') => {
  try {
    const url = `http://api.openweathermap.org/data/2.5/weather?q=${city}&appid=1ddcf9b18a5008d4e3bfa44cbe784cff&units=metric`
    const response = await axios.get(url)
    await write(to, response.data.main.temp)
  } catch (error) {
    console.error(error)
  }
}
exports.copy = copy
exports.getCityWeather = getCityWeather
